[Erp5-report] r40898 arnaud.fontaine - in /erp5/trunk/products/ERP5: Document/ PropertySheet/

nobody at svn.erp5.org nobody at svn.erp5.org
Tue Nov 30 06:34:46 CET 2010


Author: arnaud.fontaine
Date: Tue Nov 30 06:34:45 2010
New Revision: 40898

URL: http://svn.erp5.org?rev=40898&view=rev
Log:
Add Resource Measures Consistency Constraint for ZODB Property Sheets

Added:
    erp5/trunk/products/ERP5/Document/ResourceMeasuresConsistencyConstraint.py
      - copied, changed from r40897, erp5/trunk/products/ERP5/Constraint/ResourceMeasuresConsistency.py
    erp5/trunk/products/ERP5/PropertySheet/ResourceMeasuresConsistencyConstraint.py

Copied: erp5/trunk/products/ERP5/Document/ResourceMeasuresConsistencyConstraint.py (from r40897, erp5/trunk/products/ERP5/Constraint/ResourceMeasuresConsistency.py)
URL: http://svn.erp5.org/erp5/trunk/products/ERP5/Document/ResourceMeasuresConsistencyConstraint.py?p2=erp5/trunk/products/ERP5/Document/ResourceMeasuresConsistencyConstraint.py&p1=erp5/trunk/products/ERP5/Constraint/ResourceMeasuresConsistency.py&r1=40897&r2=40898&rev=40898&view=diff
==============================================================================
--- erp5/trunk/products/ERP5/PropertySheet/ResourceMeasuresConsistencyConstraint.py (added)
+++ erp5/trunk/products/ERP5/PropertySheet/ResourceMeasuresConsistencyConstraint.py [utf8] Tue Nov 30 06:34:45 2010
@@ -0,0 +1,66 @@
+##############################################################################
+#
+# Copyright (c) 2010 Nexedi SARL and Contributors. All Rights Reserved.
+#                    Arnaud Fontaine <arnaud.fontaine at nexedi.com>
+#
+# WARNING: This program as such is intended to be used by professional
+# programmers who take the whole responsability of assessing all potential
+# consequences resulting from its eventual inadequacies and bugs
+# End users who are looking for a ready-to-use solution with commercial
+# garantees and support are strongly adviced to contract a Free Software
+# Service Company
+#
+# This program is Free Software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+#
+##############################################################################
+
+class ResourceMeasuresConsistencyConstraint:
+    """
+    Define an Resource Measures Consistency Constraint for ZODB
+    Property Sheets
+    """
+    _properties = (
+        {   'id': 'message_measure_no_quantity_unit',
+            'type': 'string',
+            'description' : "Error message when the measure doesn't have a "\
+                            "valid quantity_unit",
+            'default': "Measure for metric_type '${metric_type}' doesn't "\
+                       "have a valid quantity_unit" },
+        {   'id': 'message_measure_no_quantity',
+            'type': 'string',
+            'description' : "Error message when the measure doesn't have a "\
+                            "valid quantity value",
+            'default': "Measure for metric_type '${metric_type}' doesn't "\
+                       "have a valid quantity value" },
+        {   'id': 'message_duplicate_metric_type',
+            'type': 'string',
+            'description' : 'Error message when several measures have the '\
+                            'same metric_type',
+            'default': "Several measures have the same metric_type "\
+                       "'${metric_type}'" },
+        {   'id': 'message_duplicate_default_measure',
+            'type': 'string',
+            'description' : 'Error message when several measures are '\
+                            'associated to the same unit',
+            'default': "Several measures are associated to the same unit "\
+                       "'${quantity_unit}'" },
+        {   'id': 'message_missing_metric_type',
+            'type': 'string',
+            'description' : "Error message when the metric category doesn't "\
+                            "exist",
+            'default': "Implicit measure for the management unit can't be "\
+                       "created because 'metric_type/${metric_type}' "\
+                       "category doesn't exist" },
+        )



More information about the Erp5-report mailing list
--- erp5/trunk/products/ERP5/Constraint/ResourceMeasuresConsistency.py [utf8] (original)
+++ erp5/trunk/products/ERP5/Document/ResourceMeasuresConsistencyConstraint.py [utf8] Tue Nov 30 06:34:45 2010
@@ -25,38 +25,36 @@
 #
 ##############################################################################
 
-from Products.ERP5Type.Constraint import Constraint
+from Products.ERP5Type.mixin.constraint import ConstraintMixin
+from Products.ERP5Type import PropertySheet
 
-class ResourceMeasuresConsistency(Constraint):
-  """Check that measures defined on a resource are not meaningless.
+class ResourceMeasuresConsistencyConstraint(ConstraintMixin):
+  """
+  Check that measures defined on a resource are not meaningless.
 
   Choosing quantity units for a resource without defining measures is
-  tolerated, for compatibility, although conversion between units won't be
-  possible.
+  tolerated, for compatibility, although conversion between units
+  won't be possible.
+
+  This is only relevant for ZODB Property Sheets (filesystem Property
+  Sheets rely on Products.ERP5.Constraint.ResourceMeasuresConsistency
+  instead).
   """
+  meta_type = 'ERP5 Resource Measures Consistency Constraint'
+  portal_type = 'Resource Measures Consistency Constraint'
 
-  _message_id_list = ['message_measure_no_quantity_unit',
-                      'message_measure_no_quantity',
-                      'message_duplicate_metric_type',
-                      'message_duplicate_default_measure',
-                      'message_missing_metric_type']
-
-  _message_measure = "Measure for metric_type '${metric_type}' "
-  message_measure_no_quantity_unit = \
-    _message_measure + "doesn't have a valid quantity_unit"
-  message_measure_no_quantity = \
-    _message_measure + "doesn't have a valid quantity value"
-  message_duplicate_metric_type = \
-    "Several measures have the same metric_type '${metric_type}'"
-  message_duplicate_default_measure = \
-    "Several measures are associated to the same unit '${quantity_unit}'"
-  message_missing_metric_type = \
-    "Implicit measure for the management unit can't be created" \
-    " because 'metric_type/${metric_type}' category doesn't exist."
+  property_sheets = (PropertySheet.SimpleItem,
+                     PropertySheet.Predicate,
+                     PropertySheet.Reference,
+                     PropertySheet.ResourceMeasuresConsistencyConstraint)
 
   def checkConsistency(self, obj, fixit=0):
-    """Implement here the consistency checker
     """
+    Check the object's consistency
+    """
+    if not self.test(obj):
+      return []
+
     error_list = []
     portal = obj.getPortalObject()
 

Added: erp5/trunk/products/ERP5/PropertySheet/ResourceMeasuresConsistencyConstraint.py
URL: http://svn.erp5.org/erp5/trunk/products/ERP5/PropertySheet/ResourceMeasuresConsistencyConstraint.py?rev=40898&view=auto
==============================================================================